@@ -64,11 +64,6 @@ glimpse(math)
 ## ----y summary----------------------------------------------------------------
 summary(math$math_avg)
 
-## ----enable progressr, eval = FALSE-------------------------------------------
-#  # Run this in an R console; it will not work directly within an R Markdown or Quarto block
-#  progressr::handlers(global = TRUE)
-#  progressr::handlers('cli')
-
 ## ----train gam model----------------------------------------------------------
 gam_math <- gam(
      math_avg ~ public + high_minority +
@@ -79,113 +74,119 @@ gam_math <- gam(
 
 gam_math
 
-## ----p_funs-------------------------------------------------------------------
+## ----ALEpDist-----------------------------------------------------------------
 # # To generate the code, uncomment the following lines.
-# # But it is slow because it retrains the model 1000 times,
-# # so this vignette loads a pre-created p-values object.
-# gam_math_p_funs <- create_p_funs(
-#   math,
-#   gam_math
-# )
-# saveRDS(gam_math_p_funs, file.choose())
-gam_math_p_funs <- url('https://github.com/tripartio/ale/raw/main/download/gam_math_p_funs.rds') |> 
+# # But it is slow because it retrains the model 1000 times, so this vignette loads a pre-created ALEpDist object.
+# # For standard models like mgcv::gam that store their data,
+# # there is no need to specify the data argument.
+# gam_math_p_dist <- ALEpDist(gam_math)
+# saveRDS(gam_math_p_dist, file.choose())
+gam_math_p_dist <- url('https://github.com/tripartio/ale/raw/main/download/gam_math_p_dist.0.5.0.rds') |> 
   readRDS()
 
 ## ----model bootstrap----------------------------------------------------------
-mb_gam_math <- model_bootstrap(
-  math, 
-  gam_math,
-  # Pass the p_funs object so that p-values will be generated
-  ale_options = list(p_values = gam_math_p_funs),
-  # For the GAM model coefficients, show details of all variables, parametric or not
-  tidy_options = list(parametric = TRUE),
-  # tidy_options = list(parametric = NULL),
-  boot_it = 40,  # 100 by default but reduced here for a faster demonstration
-  parallel = 2  # CRAN limit (delete this line on your own computer for faster speed)
-)
+# # To generate the code, uncomment the following lines.
+# # But bootstrapping is slow because it retrains the model, so this vignette loads a pre-created ale_boot object.
+# mb_gam_math <- ModelBoot(
+#   gam_math,
+#   # Pass the ALEpDist object so that p-values will be generated
+#   ale_p = gam_math_p_dist,
+#   # For the GAM model coefficients, show details of all variables, parametric or not
+#   tidy_options = list(parametric = TRUE),
+#   # tidy_options = list(parametric = NULL),
+#   boot_it = 100  # default
+# )
+# saveRDS(mb_gam_math, file.choose())
+mb_gam_math <- url('https://github.com/tripartio/ale/raw/main/download/mb_gam_math_stats_vignette.0.5.0.rds') |> 
+  readRDS()
 
 ## ----model_stats--------------------------------------------------------------
-mb_gam_math$model_stats
+mb_gam_math@model_stats
 
 ## ----model_coefs--------------------------------------------------------------
-mb_gam_math$model_coefs
+mb_gam_math@model_coefs
 
 ## ----model_coefs stat sig variables-------------------------------------------
-mb_gam_math$model_coefs |> 
+mb_gam_math@model_coefs |> 
   # filter is TRUE if conf.low and conf.high are both positive or both negative because
   # multiplying two numbers of the same sign results in a positive number.
   filter((conf.low * conf.high) > 0)
 
 ## ----all-ALE-plots, fig.width=7, fig.height=10--------------------------------
-mb_gam_math$ale$plots |> 
-  patchwork::wrap_plots(ncol = 2)
+mb_gam_plots <- plot(mb_gam_math)
+print(mb_gam_plots, ncol = 2)
 
-## ----model-bootstrap-without-p_funs, fig.width=7, fig.height=10---------------
-mb_gam_no_p <- model_bootstrap(
-  math, 
-  gam_math,
-  # For the GAM model coefficients, show details of all variables, parametric or not
-  tidy_options = list(parametric = TRUE),
-  # tidy_options = list(parametric = NULL),
-  boot_it = 40,  # 100 by default but reduced here for a faster demonstration
-  parallel = 2  # CRAN limit (delete this line on your own computer)
-)
+## ----model-bootstrap-without-p, fig.width=7, fig.height=10--------------------
+# # To generate the code, uncomment the following lines.
+# # But bootstrapping is slow because it retrains the model, so this vignette loads a pre-created ale_boot object.
+# mb_gam_no_p <- ModelBoot(
+#   gam_math,
+#   ale_p = NULL,  # disable ALE p-values
+#   # For the GAM model coefficients, show details of all variables, parametric or not
+#   tidy_options = list(parametric = TRUE),
+#   # tidy_options = list(parametric = NULL),
+#   boot_it = 40  # 100 by default but reduced here for a faster demonstration
+# )
+# saveRDS(mb_gam_no_p, file.choose())
+mb_gam_no_p <- url('https://github.com/tripartio/ale/raw/main/download/mb_gam_no_p_stats_vignette.0.5.0.rds') |> 
+  readRDS()
 
-mb_gam_no_p$ale$plots |> 
-  patchwork::wrap_plots(ncol = 2)
+plot(mb_gam_no_p) |> 
+  print(ncol = 2)
 
 ## ----ALE-effects-plot, fig.width=8, fig.height=6------------------------------
-mb_gam_math$ale$stats$effects_plot
+get(mb_gam_plots, type = 'effect')
 
 ## ----ALE-plot-for-public-1----------------------------------------------------
-mb_gam_math$ale$plots$public
+get(mb_gam_plots, 'public')
 
 ## ----ALE stats for public-----------------------------------------------------
-mb_gam_math$ale$stats$by_term$public
+get(mb_gam_math, 'public', stats = 'all')
 
 ## ----ALE-plot-forl-academic_ratio-1-------------------------------------------
-mb_gam_math$ale$plots$academic_ratio
+get(mb_gam_plots, 'academic_ratio')
 
 ## ----ALE stats for academic_ratio---------------------------------------------
-mb_gam_math$ale$stats$by_term$academic_ratio
+get(mb_gam_math, 'academic_ratio', stats = 'all')
 
 ## ----math-rand_norm-ALE-plot, fig.width=3.5, fig.height=3---------------------
-mb_gam_math$ale$plots$rand_norm
+get(mb_gam_plots, 'rand_norm')
 
 ## ----ALE stats for rand_norm--------------------------------------------------
-mb_gam_math$ale$stats$by_term$rand_norm
+get(mb_gam_math, 'rand_norm', stats = 'all')
 
 ## ----ale data for public------------------------------------------------------
-mb_gam_math$ale$data$public
+get(mb_gam_math, 'public')
 
 ## ----ale data for academic_ratio----------------------------------------------
-mb_gam_math$ale$data$academic_ratio
+get(mb_gam_math, 'academic_ratio')
 
 ## ----ALE-plot-for-mean_ses----------------------------------------------------
-mb_gam_math$ale$plots$mean_ses
+get(mb_gam_plots, 'mean_ses')
 
 ## ----conf_regions for mean_ses------------------------------------------------
-mb_gam_math$ale$conf_regions$by_term$mean_ses
+get(mb_gam_math, 'mean_ses', stats = 'conf_regions')
 
 ## ----text conf_regions for mean_ses-------------------------------------------
-ale:::summarize_conf_regions_in_words(mb_gam_math$ale$conf_regions$by_term$mean_ses)
+get(mb_gam_math, 'mean_ses', stats = 'conf_regions') |> 
+  ale:::summarize_conf_regions_1D_in_words()
 
 ## ----ALE-plot-for-public-2----------------------------------------------------
-mb_gam_math$ale$plots$public
+get(mb_gam_plots, 'public')
 
 ## ----conf_regions for public--------------------------------------------------
-mb_gam_math$ale$conf_regions$by_term$public
+get(mb_gam_math, 'public', stats = 'conf_regions')
 
 ## ----ALE-plot-for-rand_norm---------------------------------------------------
-mb_gam_math$ale$plots$rand_norm
+get(mb_gam_plots, 'rand_norm')
 
 ## ----conf_regions for rand_norm-----------------------------------------------
-mb_gam_math$ale$conf_regions$by_term$rand_norm
+get(mb_gam_math, 'rand_norm', stats = 'conf_regions')
 
 ## ----significant conf_regions-------------------------------------------------
-mb_gam_math$ale$conf_regions$significant
+get(mb_gam_math, stats = 'conf_sig')
 
 ## ----variables with significant conf_regions----------------------------------
-mb_gam_math$ale$conf_regions$significant$term |> 
+get(mb_gam_math, stats = 'conf_sig')$term |> 
   unique()
 
